@@ -16,22 +16,31 @@ def load_secrets():
     secrets_file = "test_pylast.yaml"
     if os.path.isfile(secrets_file):
         import yaml  # pip install pyyaml
+
         with open(secrets_file, "r") as f:  # see example_test_pylast.yaml
             doc = yaml.load(f)
     else:
         doc = {}
         try:
-            doc["username"] = os.environ['PYLAST_USERNAME'].strip()
-            doc["password_hash"] = os.environ['PYLAST_PASSWORD_HASH'].strip()
-            doc["api_key"] = os.environ['PYLAST_API_KEY'].strip()
-            doc["api_secret"] = os.environ['PYLAST_API_SECRET'].strip()
+            doc["username"] = os.environ["PYLAST_USERNAME"].strip()
+            doc["password_hash"] = os.environ["PYLAST_PASSWORD_HASH"].strip()
+            doc["api_key"] = os.environ["PYLAST_API_KEY"].strip()
+            doc["api_secret"] = os.environ["PYLAST_API_SECRET"].strip()
         except KeyError:
             pytest.skip("Missing environment variables: PYLAST_USERNAME etc.")
     return doc
 
 
-@flaky(max_runs=5, min_passes=1)
 class PyLastTestCase(unittest.TestCase):
+    def assert_startswith(self, str, prefix, start=None, end=None):
+        self.assertTrue(str.startswith(prefix, start, end))
+
+    def assert_endswith(self, str, suffix, start=None, end=None):
+        self.assertTrue(str.endswith(suffix, start, end))
+
+
+@flaky(max_runs=3, min_passes=1)
+class TestPyLastWithLastFm(PyLastTestCase):
 
     secrets = None
 
@@ -45,12 +54,15 @@ class PyLastTestCase(unittest.TestCase):
         self.username = self.__class__.secrets["username"]
         password_hash = self.__class__.secrets["password_hash"]
 
-        API_KEY = self.__class__.secrets["api_key"]
-        API_SECRET = self.__class__.secrets["api_secret"]
+        api_key = self.__class__.secrets["api_key"]
+        api_secret = self.__class__.secrets["api_secret"]
 
         self.network = pylast.LastFMNetwork(
-            api_key=API_KEY, api_secret=API_SECRET,
-            username=self.username, password_hash=password_hash)
+            api_key=api_key,
+            api_secret=api_secret,
+            username=self.username,
+            password_hash=password_hash,
+        )
 
     def helper_is_thing_hashable(self, thing):
         # Arrange
@@ -119,5 +131,5 @@ class PyLastTestCase(unittest.TestCase):
         self.assertNotEqual(thing1, thing2)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main(failfast=True)
